@@ -15,7 +15,7 @@ from time import time
 
 @click.command()
 
-@click.argument('file_paths', default=[])
+@click.argument('file_paths')
 @click.option('--save_path', default='')
 def main(file_paths, save_path=None):
     face_anonymizer(file_paths, save_path)
